@@ -279,6 +279,7 @@ function sent_conf_message_sent_do() {
    $sent_conf_orig_subject = '';
    $sent_conf_orig_sender = '';
    $sent_conf_mbox_list = '';
+
    if ($sent_conf_message_style > 2 && $sent_conf_enable_orig_msg_options 
    && (strpos($action, 'reply') !== FALSE || strpos($action, 'forward') !== FALSE))
    {
@@ -361,7 +362,7 @@ function sent_conf_check_is_sent_do() {
           $sent_conf_show_headers, $sent_conf_orig_reply_msg,
           $sent_conf_orig_subject, $sent_conf_orig_sender, 
           $sent_conf_enable_orig_msg_options, $compose_new_win,
-          $sent_conf_mbox_list, $blockedAddresses;
+          $sent_conf_mbox_list, $blockedAddresses, $mailbox;
 
    compatibility_sqextractGlobalVar('sent_conf_message_sent_status');
    compatibility_sqextractGlobalVar('sent_conf_orig_reply_msg');
@@ -406,15 +407,23 @@ function sent_conf_check_is_sent_do() {
       // of displayPageHeader(), so we need to avoid
       // an endless recursion loop here
       //
-      global $color, $sent_conf_count;
-      if (!$sent_conf_count)
+      if ($sent_conf_message_style > 2)
       {
-         $sent_conf_count = 1;
-         displayPageHeader($color, 'None');
-      }
-      else
-      {
-         return;
+
+         global $color, $sent_conf_count;
+         if (!$sent_conf_count)
+         {
+            $sent_conf_count = 1;
+            if (!empty($mailbox))
+               displayPageHeader($color, $mailbox);
+            else
+               displayPageHeader($color, 'None');
+         }
+         else
+         {
+            return;
+         }
+
       }
 
 
@@ -541,7 +550,7 @@ function sent_conf_check_is_sent_do() {
          // code stolen from /src/read_body.php as 
          // well as Wolf Bergenheim's Todo plugin
          //
-         global $color, $base_uri, $mailbox, $sort, $startMessage,
+         global $color, $base_uri, $sort, $startMessage,
                 $sent_logo, $sent_logo_width, $sent_logo_height;
          $urlMailbox = urlencode($mailbox);
 
@@ -554,9 +563,11 @@ function sent_conf_check_is_sent_do() {
             . '<SMALL>';
          if ($compose_new_win)
          {
-            echo '<A HREF="' . $base_uri . 'src/'
-               . "compose.php?newmessage=1\">"
-               . _("Compose") . '</A></SMALL>';
+            echo '<A href="#" onClick="return self.close()">'
+               . _("Close") . '</A></SMALL>';
+//            echo '<A HREF="' . $base_uri . 'src/'
+//               . "compose.php?newmessage=1\">"
+//               . _("Compose") . '</A></SMALL>';
          }
          else
          {
@@ -736,9 +747,11 @@ function sent_conf_check_is_sent_do() {
             . '<SMALL>';
          if ($compose_new_win)
          {
-            echo '<A HREF="' . $base_uri . 'src/'
-               . "compose.php?newmessage=1\">"
-               . _("Compose") . '</A></SMALL>';
+            echo '<A href="#" onClick="return self.close()">'
+               . _("Close") . '</A></SMALL>';
+//            echo '<A HREF="' . $base_uri . 'src/'
+//               . "compose.php?newmessage=1\">"
+//               . _("Compose") . '</A></SMALL>';
          }
          else
          {
